@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,8 @@ use NeedRestart::Utils;
 
 my $LOGPREF = '[LXC]';
 
-needrestart_cont_register(__PACKAGE__);
+needrestart_cont_register(__PACKAGE__)
+    unless($<);
 
 sub new {
     my $class = shift;
@@ -42,6 +43,10 @@ sub new {
     die "Could not get NS PID of #1!\n" unless(defined($self->{nspid}));
 
     $self->{lxc} = {};
+    $self->{lxd} = {};
+
+    $self->{has_lxd} = -x q(/usr/bin/lxc);
+
     return bless $self, $class;
 }
 
@@ -49,6 +54,7 @@ sub check {
     my $self = shift;
     my $pid = shift;
     my $bin = shift;
+    my $norestart = shift;
     my $ns = $self->get_nspid($pid);
 
     # stop here if no dedicated PID namespace is used
@@ -66,12 +72,18 @@ sub check {
     }
 
     # look for LXC cgroups
-    return 0 unless($cg =~ /^\d+:[^:]+:\/lxc\/(.+)$/m);
+    return unless($cg =~ /^\d+:[^:]+:\/lxc\/([^\/\n]+)($|\/)/m);
 
     my $name = $1;
-    print STDERR "$LOGPREF #$pid is part of LXC container '$name' and should be restarted\n" if($self->{debug});
+    my $type = ($self->{has_lxd} && -d qq(/var/lib/lxd/containers/$name) ? 'LXD' : 'LXC');
+    unless($norestart) {
+	print STDERR "$LOGPREF #$pid is part of $type container '$name' and should be restarted\n" if($self->{debug});
 
-    $self->{lxc}->{$name}++;
+	$self->{lc($type)}->{$name}++;
+    }
+    else {
+	print STDERR "$LOGPREF #$pid is part of $type container '$name'\n" if($self->{debug});
+    }
 
     return 1;
 }
@@ -79,9 +91,11 @@ sub check {
 sub get {
     my $self = shift;
 
-    return map {
+    return (map {
 	($_ => [qw(lxc-stop --reboot --name), $_]);
-    } keys %{ $self->{lxc} };
+    } keys %{ $self->{lxc} }), (map {
+	($_ => [qw(lxc restart), $_]);
+    } keys %{ $self->{lxd} });
 }
 
 1;
