@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,8 @@ use NeedRestart::Utils;
 
 my $LOGPREF = '[docker]';
 
-needrestart_cont_register(__PACKAGE__);
+needrestart_cont_register(__PACKAGE__)
+    unless($<);
 
 sub new {
     my $class = shift;
@@ -49,6 +50,7 @@ sub check {
     my $self = shift;
     my $pid = shift;
     my $bin = shift;
+    my $norestart = shift;
     my $ns = $self->get_nspid($pid);
 
     # stop here if no dedicated PID namespace is used
@@ -70,9 +72,14 @@ sub check {
 
     my $name = $1;
     $name =~ s/^([\da-f]{12})[\da-f]{52}$/$1/;
-    print STDERR "$LOGPREF #$pid is part of docker container '$name' and should be restarted\n" if($self->{debug});
+    unless($norestart) {
+	print STDERR "$LOGPREF #$pid is part of docker container '$name' and should be restarted\n" if($self->{debug});
 
-    $self->{docker}->{$name}++;
+	$self->{docker}->{$name}++;
+    }
+    else {
+	print STDERR "$LOGPREF #$pid is part of docker container '$name'\n" if($self->{debug});
+    }
 
     return 1;
 }
