@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -31,13 +31,19 @@ use NeedRestart::Kernel;
 use NeedRestart::Strings;
 use POSIX qw(uname);
 use Sort::Naturally;
+use Locale::TextDomain 'needrestart';
 use Fcntl qw(SEEK_SET);
 
+use constant {
+    NRK_LNX_GETVER_HELPER => q(/usr/lib/needrestart/vmlinuz-get-version),
+};
+
 require Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
     nr_linux_version_x86
+    nr_linux_version_generic
 );
 
 my $LOGPREF = '[Kernel/Linux]';
@@ -73,7 +79,40 @@ sub nr_linux_version_x86($$) {
 	return undef;
     }
 
-    return $buf;
+    return ($buf, 1);
+}
+
+sub nr_linux_version_generic($$) {
+    my $debug = shift;
+    my $fn = shift;
+
+    # use helper script to get version string
+    if(-x NRK_LNX_GETVER_HELPER) {
+	my $fh = nr_fork_pipe($debug, NRK_LNX_GETVER_HELPER, $fn, $debug);
+	if($fh) {
+	    my $verstr = <$fh>;
+	    close($fh);
+
+	    if($verstr) {
+		chomp($verstr);
+		return ($verstr, 1) ;
+	    }
+	}
+    }
+    else {
+	print STDERR "$LOGPREF ".(NRK_LNX_GETVER_HELPER)." is n/a\n" if($debug);
+    }
+
+    # fallback trying filename
+    $fn =~ s/[^-]*-//;
+    $fn =~ s/\.img$//;
+    if($fn =~ /^\d+\.\d+/) {
+	print STDERR "$LOGPREF version from filename: $fn\n" if($debug);
+
+	return ($fn, 0);
+    }
+
+    return undef;
 }
 
 sub nr_kernel_check_real($$) {
@@ -82,15 +121,22 @@ sub nr_kernel_check_real($$) {
     my %vars;
 
     my ($sysname, $nodename, $release, $version, $machine) = uname;
+    my $is_x86 = ($machine =~ /^(i\d86|x86_64)$/);
     $vars{KVERSION} = $release;
 
     die "$LOGPREF Not running on Linux!\n" unless($sysname eq 'Linux');
 
-    my @kfiles = reverse nsort </boot/vmlinu*>;
-    $ui->progress_prep(scalar @kfiles, 'Scanning linux images...');
+    my %kfiles = map {
+	$_ => 1,
+    } grep {
+	# filter initrd images
+	(!m@^/boot/init@);
+    } </boot/vmlinu* /boot/*.img>;
+
+    $ui->progress_prep(scalar keys %kfiles, __ 'Scanning linux images...');
 
     my %kernels;
-    foreach my $fn (@kfiles) {
+    foreach my $fn (reverse nsort keys %kfiles) {
 	$ui->progress_step;
 	my $stat = nr_stat($fn);
 
@@ -104,20 +150,23 @@ sub nr_kernel_check_real($$) {
 	    next;
 	}
 
-	my $verstr = nr_linux_version_x86($debug, $fn);
-	unless(defined($verstr)) {
-	    $verstr = nr_strings($debug, qr/^(Linux version )?\d\.\d+\S*\s/, $fn);
-
-	    unless(defined($verstr)) {
-		print STDERR "$LOGPREF Could not get version string from $fn.\n" if($debug);
-		next;
-	    }
+	my $verstr;
+	my $abidtc;
+	if($is_x86) {
+	    ($verstr, $abidtc) = nr_linux_version_x86($debug, $fn);
 	}
+	unless(defined($verstr)) {
+	    ($verstr, $abidtc) = nr_linux_version_generic($debug, $fn);
+	}
+	unless(defined($verstr)) {
+	    print STDERR "$LOGPREF Could not get version string from $fn.\n" if($debug);
+	    next;
+	}
+        $vars{ABIDETECT} += $abidtc;
 
 	my $iversion = $verstr;
 	$iversion =~ s/^Linux version //;
-	chomp($iversion);
-	$iversion =~ s/\s.+$//;
+	$iversion =~ s/\s.+$//s;
 	$kernels{$iversion} = (index($verstr, $release) != -1 && index($verstr, $version) != -1);
 
 	print STDERR "$LOGPREF $fn => $verstr [$iversion]".($kernels{$iversion} ? '*' : '')."\n" if($debug);
@@ -133,7 +182,7 @@ sub nr_kernel_check_real($$) {
     print STDERR "$LOGPREF Expected linux version: $vars{EVERSION}\n" if($debug);
 
     return (NRK_VERUPGRADE, %vars) if($vars{KVERSION} ne $vars{EVERSION});
-    return (NRK_ABIUPGRADE, %vars) unless($kernels{$release});
+    return (NRK_ABIUPGRADE, %vars) unless(!$is_x86 || $kernels{$release});
     return (NRK_NOUPGRADE, %vars);
 }
 
