@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2014 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@ use NeedRestart::Kernel;
 use NeedRestart::Strings;
 use POSIX qw(uname);
 use Sort::Naturally;
+use Locale::TextDomain 'needrestart';
 
 my $LOGPREF = '[Kernel/kFreeBSD]';
 
@@ -45,13 +46,18 @@ sub nr_kernel_check_real($$) {
     die "$LOGPREF Not running on GNU/kFreeBSD!\n" unless($sysname eq 'GNU/kFreeBSD');
 
     my @kfiles = reverse nsort </boot/kfreebsd-*>;
-    $ui->progress_prep(scalar @kfiles, 'Scanning kernel images...');
+    $ui->progress_prep(scalar @kfiles, __ 'Scanning kfreebsd images...');
 
     my %kernels;
     foreach my $fn (@kfiles) {
 	$ui->progress_step;
 	my $stat = nr_stat($fn);
 
+	unless(defined($stat)) {
+	    print STDERR "$LOGPREF could not stat(2) on $fn\n" if($debug);
+	    next;
+	}
+
 	if($stat->{size} < 1000000) {
 	    print STDERR "$LOGPREF $fn seems to be too small\n" if($debug);
 	    next;
@@ -75,12 +81,12 @@ sub nr_kernel_check_real($$) {
     $ui->progress_fin;
 
     unless(scalar keys %kernels) {
-	print STDERR "$LOGPREF Did not find any kernel images (/boot/kfreebsd-*)!\n" if($debug);
+	print STDERR "$LOGPREF Did not find any kfreebsd images (/boot/kfreebsd-*)!\n" if($debug);
 	return (NRK_UNKNOWN, %vars);
     }
 
-    ($vars{EVERSION}) = reverse nsort keys %kernels;
-    print STDERR "$LOGPREF Expected kernel version: $vars{EVERSION}\n" if($debug);
+    ($vars{EVERSION}) = reverse sort { nr_kernel_vcmp($a, $b); } keys %kernels;
+    print STDERR "$LOGPREF Expected kfreebsd version: $vars{EVERSION}\n" if($debug);
 
     return (NRK_VERUPGRADE, %vars) if($vars{KVERSION} ne $vars{EVERSION});
     return (NRK_ABIUPGRADE, %vars) unless($kernels{$release});
