@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -62,12 +62,12 @@ sub dcres(@) {
 
 sub new {
     my $class = shift;
-    my $debug = shift;
+    my $verbosity = shift;
 
     dcres( x_loadtemplatefile(DCTMPL) ) if(-r DCTMPL);
 
     return bless {
-	debug => $debug
+	verbosity => $verbosity,
     }, $class;
 }
 
@@ -92,18 +92,45 @@ sub announce_abi {
     $self->_announce('needrestart/ui-kernel_announce_abi', @_);
 }
 
-
 sub announce_ver {
     my $self = shift;
 
     $self->_announce('needrestart/ui-kernel_announce_ver', @_);
 }
 
+sub announce_ehint {
+    my $self = shift;
+    my %vars = @_;
+    my $templ = q(needrestart/ui-ehint_announce);
+
+    foreach my $k (keys %vars) {
+	dcres( subst($templ, $k, $vars{$k}) );
+    }
+
+    dcres( fset($templ, 'seen', 0) );
+    dcres( settitle('needrestart/ui-ehint_title') );
+    dcres( input('critical', $templ) );
+    dcres( go );
+}
+
 
 sub notice {
     my $self = shift;
     my $out = shift;
 
+    return unless($self->{verbosity});
+
+    my $indent = ' ';
+    $indent .= $1 if($out =~ /^(\s+)/);
+
+    $self->wprint(\*STDERR, '', $indent, "$out\n");
+}
+
+
+sub command {
+    my $self = shift;
+    my $out = shift;
+
     print STDERR "$out\n";
 }
 
@@ -144,11 +171,6 @@ sub query_pkgs($$$$$$) {
 
     my ($s) = dcres( get('needrestart/ui-query_pkgs') );
 
-    stop;
-
-    # Debconf kills STDOUT... try to restore it
-    open(STDOUT, '> /dev/tty') || open(STDOUT, '>&2');
-
     # user has canceled
     return unless(defined($s));
     return if($r eq 'backup');
@@ -156,8 +178,10 @@ sub query_pkgs($$$$$$) {
     # get selected rc.d script
     my @s = split(/, /, $s);
 
-    # restart each selected service script
-    &$cb($_) for @s;
+    $self->runcmd(sub {
+	# restart each selected service script
+	&$cb($_) for @s;
+		  });
 }
 
 sub query_conts($$$$$$) {
@@ -196,11 +220,6 @@ sub query_conts($$$$$$) {
 
     my ($s) = dcres( get('needrestart/ui-query_conts') );
 
-    stop;
-
-    # Debconf kills STDOUT... try to restore it
-    open(STDOUT, '> /dev/tty') || open(STDOUT, '>&2');
-
     # user has canceled
     return unless(defined($s));
     return if($r eq 'backup');
@@ -208,8 +227,23 @@ sub query_conts($$$$$$) {
     # get selected rc.d script
     my @s = split(/, /, $s);
 
-    # restart each selected service script
-    &$cb($_) for @s;
+    $self->runcmd(sub {
+	# restart each selected service script
+	&$cb($_) for @s;
+		  });
+}
+
+sub runcmd {
+    my $self = shift;
+
+    local *STDOUT;
+
+    # Debconf kills STDOUT... try to restore it
+    open(STDOUT, '> /dev/tty') || open(STDOUT, '>&2');
+
+    $self->SUPER::runcmd(@_);
+
+    close(STDOUT);
 }
 
 1;
