@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2014 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -40,10 +40,11 @@ our @EXPORT = qw(
     nr_readlink
     nr_stat
     nr_fork_pipe
+    nr_fork_pipew
     nr_fork_pipe2
 );
 
-my %ptable = map {$_->pid => $_} @{ new Proc::ProcessTable(enable_ttys => 0)->table };
+my %ptable = map {$_->pid => $_} @{ new Proc::ProcessTable(enable_ttys => 1)->table };
 
 sub nr_ptable() {
     return \%ptable;
@@ -140,6 +141,25 @@ sub nr_fork_pipe($@) {
     \*HPIPE
 }
 
+sub nr_fork_pipew($@) {
+    my $debug = shift;
+
+    my $pid = open(HPIPE, '|-');
+    defined($pid) || die "Can't fork: $!\n";
+
+    if($pid == 0) {
+	close(STDOUT);
+	close(STDERR) unless($debug);
+
+	undef $ENV{LANG};
+
+	exec(@_);
+	exit;
+    }
+
+    \*HPIPE
+}
+
 sub nr_fork_pipe2($@) {
     my $debug = shift;
 
